# APIs for Windows 32-bit MSVC 7.1 runtime library (msvcr71).
# Format:  rettype, retname, callconv, exactname, arglist(type, name)
#          arglist type is one of ['int', 'void *']
#          arglist name is one of [None, 'funcptr', 'obj', 'ptr']

api_defs = {
    'msvcr71.main_entry':( 'int', None, 'stdcall', 'msvcr71.main_entry', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.$i10_output':( 'int', None, 'cdecl', 'msvcr71.$I10_OUTPUT', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'msvcr71.??0__non_rtti_object@@qae@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??0__non_rtti_object@@QAE@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??0__non_rtti_object@@qae@pbd@z':( 'int', None, 'stdcall', 'msvcr71.??0__non_rtti_object@@QAE@PBD@Z', ( ('int', None),) ),
    'msvcr71.??0bad_cast@@aae@pbqbd@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_cast@@AAE@PBQBD@Z', ( ('int', None),) ),
    'msvcr71.??0bad_cast@@qae@abqbd@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_cast@@QAE@ABQBD@Z', ( ('int', None),) ),
    'msvcr71.??0bad_cast@@qae@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_cast@@QAE@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??0bad_cast@@qae@pbd@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_cast@@QAE@PBD@Z', ( ('int', None),) ),
    'msvcr71.??0bad_typeid@@qae@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_typeid@@QAE@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??0bad_typeid@@qae@pbd@z':( 'int', None, 'stdcall', 'msvcr71.??0bad_typeid@@QAE@PBD@Z', ( ('int', None),) ),
    'msvcr71.??0exception@@qae@abqbd@z':( 'int', None, 'stdcall', 'msvcr71.??0exception@@QAE@ABQBD@Z', ( ('int', None),) ),
    'msvcr71.??0exception@@qae@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??0exception@@QAE@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??0exception@@qae@xz':( 'int', None, 'stdcall', 'msvcr71.??0exception@@QAE@XZ', () ),
    'msvcr71.??1__non_rtti_object@@uae@xz':( 'int', None, 'stdcall', 'msvcr71.??1__non_rtti_object@@UAE@XZ', () ),
    'msvcr71.??1bad_cast@@uae@xz':( 'int', None, 'stdcall', 'msvcr71.??1bad_cast@@UAE@XZ', () ),
    'msvcr71.??1bad_typeid@@uae@xz':( 'int', None, 'stdcall', 'msvcr71.??1bad_typeid@@UAE@XZ', () ),
    'msvcr71.??1exception@@uae@xz':( 'int', None, 'stdcall', 'msvcr71.??1exception@@UAE@XZ', () ),
    'msvcr71.??1type_info@@uae@xz':( 'int', None, 'stdcall', 'msvcr71.??1type_info@@UAE@XZ', () ),
    'msvcr71.??2@yapaxi@z':( 'int', None, 'cdecl', 'msvcr71.??2@YAPAXI@Z', (('DWORD', None),) ),
    'msvcr71.??3@yaxpax@z':( 'void', None, 'cdecl', 'msvcr71.??3@YAXPAX@Z', (('void *', 'ptr'),) ),
    'msvcr71.??4__non_rtti_object@@qaeaav0@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??4__non_rtti_object@@QAEAAV0@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??4bad_cast@@qaeaav0@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??4bad_cast@@QAEAAV0@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??4bad_typeid@@qaeaav0@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??4bad_typeid@@QAEAAV0@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??4exception@@qaeaav0@abv0@@z':( 'int', None, 'stdcall', 'msvcr71.??4exception@@QAEAAV0@ABV0@@Z', ( ('int', None),) ),
    'msvcr71.??8type_info@@qbehabv0@@z':( 'int', None, 'stdcall', 'msvcr71.??8type_info@@QBEHABV0@@Z', ( ('int', None),) ),
    'msvcr71.??9type_info@@qbehabv0@@z':( 'int', None, 'stdcall', 'msvcr71.??9type_info@@QBEHABV0@@Z', ( ('int', None),) ),
    'msvcr71.??_7__non_rtti_object@@6b@':( 'int', None, 'cdecl', 'msvcr71.??_7__non_rtti_object@@6B@', () ),
    'msvcr71.??_7bad_cast@@6b@':( 'int', None, 'cdecl', 'msvcr71.??_7bad_cast@@6B@', () ),
    'msvcr71.??_7bad_typeid@@6b@':( 'int', None, 'cdecl', 'msvcr71.??_7bad_typeid@@6B@', () ),
    'msvcr71.??_7exception@@6b@':( 'int', None, 'bfastcall', 'msvcr71.??_7exception@@6B@', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.??_fbad_cast@@qaexxz':( 'int', None, 'stdcall', 'msvcr71.??_Fbad_cast@@QAEXXZ', () ),
    'msvcr71.??_fbad_typeid@@qaexxz':( 'int', None, 'stdcall', 'msvcr71.??_Fbad_typeid@@QAEXXZ', () ),
    'msvcr71.??_u@yapaxi@z':( 'int', None, 'cdecl', 'msvcr71.??_U@YAPAXI@Z', (('int', None),) ),
    'msvcr71.??_v@yaxpax@z':( 'void', None, 'cdecl', 'msvcr71.??_V@YAXPAX@Z', (('void *', 'ptr'),) ),
    'msvcr71.?_query_new_handler@@yap6ahi@zxz':( 'int', None, 'cdecl', 'msvcr71.?_query_new_handler@@YAP6AHI@ZXZ', () ),
    'msvcr71.?_query_new_mode@@yahxz':( 'int', None, 'cdecl', 'msvcr71.?_query_new_mode@@YAHXZ', () ),
    'msvcr71.?_set_new_handler@@yap6ahi@zp6ahi@z@z':( 'int', None, 'cdecl', 'msvcr71.?_set_new_handler@@YAP6AHI@ZP6AHI@Z@Z', (('int', None),) ),
    'msvcr71.?_set_new_mode@@yahh@z':( 'int', None, 'cdecl', 'msvcr71.?_set_new_mode@@YAHH@Z', (('int', None),) ),
    'msvcr71.?_set_se_translator@@yap6axipau_exception_pointers@@@zp6axi0@z@z':( 'int', None, 'cdecl', 'msvcr71.?_set_se_translator@@YAP6AXIPAU_EXCEPTION_POINTERS@@@ZP6AXI0@Z@Z', (('int', None),) ),
    'msvcr71.?before@type_info@@qbehabv1@@z':( 'int', None, 'stdcall', 'msvcr71.?before@type_info@@QBEHABV1@@Z', ( ('int', None),) ),
    'msvcr71.?name@type_info@@qbepbdxz':( 'int', None, 'stdcall', 'msvcr71.?name@type_info@@QBEPBDXZ', () ),
    'msvcr71.?raw_name@type_info@@qbepbdxz':( 'int', None, 'cdecl', 'msvcr71.?raw_name@type_info@@QBEPBDXZ', () ),
    'msvcr71.?set_new_handler@@yap6axxzp6axxz@z':( 'int', None, 'cdecl', 'msvcr71.?set_new_handler@@YAP6AXXZP6AXXZ@Z', (('int', None),) ),
    'msvcr71.?set_terminate@@yap6axxzp6axxz@z':( 'int', None, 'cdecl', 'msvcr71.?set_terminate@@YAP6AXXZP6AXXZ@Z', (('int', None),) ),
    'msvcr71.?set_unexpected@@yap6axxzp6axxz@z':( 'int', None, 'cdecl', 'msvcr71.?set_unexpected@@YAP6AXXZP6AXXZ@Z', (('int', None),) ),
    'msvcr71.?swprintf@@yahpagipbgzz':( 'int', None, 'cdecl', 'msvcr71.?swprintf@@YAHPAGIPBGZZ', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.?swprintf@@yahpa_wipb_wzz':( 'int', None, 'cdecl', 'msvcr71.?swprintf@@YAHPA_WIPB_WZZ', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.?terminate@@yaxxz':( 'int', None, 'stdcall', 'msvcr71.?terminate@@YAXXZ', (('int', None),) ),
    'msvcr71.?unexpected@@yaxxz':( 'int', None, 'stdcall', 'msvcr71.?unexpected@@YAXXZ', (('int', None),) ),
    'msvcr71.?vswprintf@@yahpagipbgpad@z':( 'int', None, 'cdecl', 'msvcr71.?vswprintf@@YAHPAGIPBGPAD@Z', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.?vswprintf@@yahpa_wipb_wpad@z':( 'int', None, 'cdecl', 'msvcr71.?vswprintf@@YAHPA_WIPB_WPAD@Z', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.?what@exception@@ubepbdxz':( 'int', None, 'stdcall', 'msvcr71.?what@exception@@UBEPBDXZ', () ),
    'msvcr71._ciacos':( 'int', None, 'cdecl', 'msvcr71._CIacos', () ),
    'msvcr71._ciasin':( 'int', None, 'cdecl', 'msvcr71._CIasin', () ),
    'msvcr71._ciatan':( 'int', None, 'cdecl', 'msvcr71._CIatan', () ),
    'msvcr71._ciatan2':( 'int', None, 'cdecl', 'msvcr71._CIatan2', () ),
    'msvcr71._cicos':( 'int', None, 'cdecl', 'msvcr71._CIcos', () ),
    'msvcr71._cicosh':( 'int', None, 'cdecl', 'msvcr71._CIcosh', () ),
    'msvcr71._ciexp':( 'int', None, 'cdecl', 'msvcr71._CIexp', () ),
    'msvcr71._cifmod':( 'int', None, 'cdecl', 'msvcr71._CIfmod', () ),
    'msvcr71._cilog':( 'int', None, 'cdecl', 'msvcr71._CIlog', () ),
    'msvcr71._cilog10':( 'int', None, 'cdecl', 'msvcr71._CIlog10', () ),
    'msvcr71._cipow':( 'int', None, 'cdecl', 'msvcr71._CIpow', () ),
    'msvcr71._cisin':( 'int', None, 'cdecl', 'msvcr71._CIsin', () ),
    'msvcr71._cisinh':( 'int', None, 'cdecl', 'msvcr71._CIsinh', () ),
    'msvcr71._cisqrt':( 'int', None, 'cdecl', 'msvcr71._CIsqrt', () ),
    'msvcr71._citan':( 'int', None, 'cdecl', 'msvcr71._CItan', () ),
    'msvcr71._citanh':( 'int', None, 'cdecl', 'msvcr71._CItanh', () ),
    'msvcr71._crt_rtc_init':( 'int', None, 'cdecl', 'msvcr71._CRT_RTC_INIT', () ),
    'msvcr71._cxxthrowexception':( 'void', None, 'stdcall', 'msvcr71._CxxThrowException', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._eh_prolog':( 'int', None, 'cdecl', 'msvcr71._EH_prolog', () ),
    'msvcr71._getdays':( 'int', None, 'cdecl', 'msvcr71._Getdays', () ),
    'msvcr71._getmonths':( 'int', None, 'cdecl', 'msvcr71._Getmonths', () ),
    'msvcr71._gettnames':( 'int', None, 'cdecl', 'msvcr71._Gettnames', () ),
    'msvcr71._huge':( 'int', None, 'cdecl', 'msvcr71._HUGE', () ),
    'msvcr71._strftime':( 'int', None, 'cdecl', 'msvcr71._Strftime', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._xcptfilter':( 'int', None, 'cdecl', 'msvcr71._XcptFilter', (('int', None), ('int', None)) ),
    'msvcr71.__cppxcptfilter':( 'int', None, 'cdecl', 'msvcr71.__CppXcptFilter', (('int', None), ('int', None)) ),
    'msvcr71.__cxxcallunwinddtor':( 'int', None, 'cdecl', 'msvcr71.__CxxCallUnwindDtor', (('void *', 'funcptr'), ('int', None)) ),
    'msvcr71.__cxxcallunwindvecdtor':( 'int', None, 'cdecl', 'msvcr71.__CxxCallUnwindVecDtor', (('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__cxxdetectrethrow':( 'int', None, 'cdecl', 'msvcr71.__CxxDetectRethrow', (('int', None),) ),
    'msvcr71.__cxxexceptionfilter':( 'int', None, 'cdecl', 'msvcr71.__CxxExceptionFilter', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__cxxframehandler':( 'int', None, 'bfastcall', 'msvcr71.__CxxFrameHandler', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__cxxlongjmpunwind':( 'int', None, 'stdcall', 'msvcr71.__CxxLongjmpUnwind', (('int', None),) ),
    'msvcr71.__cxxqueryexceptionsize':( 'int', None, 'cdecl', 'msvcr71.__CxxQueryExceptionSize', () ),
    'msvcr71.__cxxregisterexceptionobject':( 'int', None, 'cdecl', 'msvcr71.__CxxRegisterExceptionObject', (('int', None), ('void *', 'ptr')) ),
    'msvcr71.__cxxunregisterexceptionobject':( 'int', None, 'cdecl', 'msvcr71.__CxxUnregisterExceptionObject', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__destructexceptionobject':( 'int', None, 'cdecl', 'msvcr71.__DestructExceptionObject', (('int', None),) ),
    'msvcr71.__rtcasttovoid':( 'int', None, 'cdecl', 'msvcr71.__RTCastToVoid', () ),
    'msvcr71.__rtdynamiccast':( 'int', None, 'cdecl', 'msvcr71.__RTDynamicCast', ( ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__rttypeid':( 'int', None, 'cdecl', 'msvcr71.__RTtypeid', (('int', None),) ),
    'msvcr71.__stringtold':( 'int', None, 'cdecl', 'msvcr71.__STRINGTOLD', (('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.___lc_codepage_func':( 'int', None, 'cdecl', 'msvcr71.___lc_codepage_func', () ),
    'msvcr71.___lc_collate_cp_func':( 'int', None, 'cdecl', 'msvcr71.___lc_collate_cp_func', () ),
    'msvcr71.___lc_handle_func':( 'int', None, 'cdecl', 'msvcr71.___lc_handle_func', () ),
    'msvcr71.___mb_cur_max_func':( 'int', None, 'cdecl', 'msvcr71.___mb_cur_max_func', () ),
    'msvcr71.___setlc_active_func':( 'int', None, 'cdecl', 'msvcr71.___setlc_active_func', () ),
    'msvcr71.___unguarded_readlc_active_add_func':( 'int', None, 'cdecl', 'msvcr71.___unguarded_readlc_active_add_func', () ),
    'msvcr71.__argc':( 'int', None, 'cdecl', 'msvcr71.__argc', () ),
    'msvcr71.__argv':( 'int', None, 'cdecl', 'msvcr71.__argv', () ),
    'msvcr71.__badioinfo':( 'int', None, 'cdecl', 'msvcr71.__badioinfo', () ),
    'msvcr71.__buffer_overrun':( 'int', None, 'cdecl', 'msvcr71.__buffer_overrun', () ),
    'msvcr71.__crtcomparestringa':( 'int', None, 'cdecl', 'msvcr71.__crtCompareStringA', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.__crtcomparestringw':( 'int', None, 'cdecl', 'msvcr71.__crtCompareStringW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__crtgetlocaleinfow':( 'int', None, 'cdecl', 'msvcr71.__crtGetLocaleInfoW', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__crtgetstringtypew':( 'int', None, 'cdecl', 'msvcr71.__crtGetStringTypeW', (('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.__crtlcmapstringa':( 'int', None, 'cdecl', 'msvcr71.__crtLCMapStringA', (('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__crtlcmapstringw':( 'int', None, 'cdecl', 'msvcr71.__crtLCMapStringW', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.__dllonexit':( 'int', None, 'cdecl', 'msvcr71.__dllonexit', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__doserrno':( 'int', None, 'cdecl', 'msvcr71.__doserrno', () ),
    'msvcr71.__fpecode':( 'int', None, 'cdecl', 'msvcr71.__fpecode', () ),
    'msvcr71.__getmainargs':( 'int', None, 'cdecl', 'msvcr71.__getmainargs', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__initenv':( 'int', None, 'cdecl', 'msvcr71.__initenv', () ),
    'msvcr71.__iob_func':( 'int', None, 'cdecl', 'msvcr71.__iob_func', () ),
    'msvcr71.__isascii':( 'int', None, 'cdecl', 'msvcr71.__isascii', (('int', None),) ),
    'msvcr71.__iscsym':( 'int', None, 'cdecl', 'msvcr71.__iscsym', (('int', None),) ),
    'msvcr71.__iscsymf':( 'int', None, 'cdecl', 'msvcr71.__iscsymf', (('int', None),) ),
    'msvcr71.__lc_clike':( 'int', None, 'bfastcall', 'msvcr71.__lc_clike', (('int', None),) ),
    'msvcr71.__lc_codepage':( 'int', None, 'cdecl', 'msvcr71.__lc_codepage', () ),
    'msvcr71.__lc_collate_cp':( 'int', None, 'cdecl', 'msvcr71.__lc_collate_cp', () ),
    'msvcr71.__lc_handle':( 'int', None, 'cdecl', 'msvcr71.__lc_handle', () ),
    'msvcr71.__lconv_init':( 'int', None, 'cdecl', 'msvcr71.__lconv_init', () ),
    'msvcr71.__mb_cur_max':( 'int', None, 'bfastcall', 'msvcr71.__mb_cur_max', (('int', None),) ),
    'msvcr71.__p___argc':( 'int', None, 'cdecl', 'msvcr71.__p___argc', () ),
    'msvcr71.__p___argv':( 'int', None, 'cdecl', 'msvcr71.__p___argv', () ),
    'msvcr71.__p___initenv':( 'int', None, 'cdecl', 'msvcr71.__p___initenv', () ),
    'msvcr71.__p___mb_cur_max':( 'int', None, 'cdecl', 'msvcr71.__p___mb_cur_max', () ),
    'msvcr71.__p___wargv':( 'int', None, 'cdecl', 'msvcr71.__p___wargv', () ),
    'msvcr71.__p___winitenv':( 'int', None, 'cdecl', 'msvcr71.__p___winitenv', () ),
    'msvcr71.__p__acmdln':( 'int', None, 'cdecl', 'msvcr71.__p__acmdln', () ),
    'msvcr71.__p__amblksiz':( 'int', None, 'cdecl', 'msvcr71.__p__amblksiz', () ),
    'msvcr71.__p__commode':( 'int', None, 'cdecl', 'msvcr71.__p__commode', () ),
    'msvcr71.__p__daylight':( 'int', None, 'cdecl', 'msvcr71.__p__daylight', () ),
    'msvcr71.__p__dstbias':( 'int', None, 'cdecl', 'msvcr71.__p__dstbias', () ),
    'msvcr71.__p__environ':( 'int', None, 'cdecl', 'msvcr71.__p__environ', () ),
    'msvcr71.__p__fileinfo':( 'int', None, 'cdecl', 'msvcr71.__p__fileinfo', () ),
    'msvcr71.__p__fmode':( 'int', None, 'cdecl', 'msvcr71.__p__fmode', () ),
    'msvcr71.__p__iob':( 'int', None, 'cdecl', 'msvcr71.__p__iob', () ),
    'msvcr71.__p__mbcasemap':( 'int', None, 'cdecl', 'msvcr71.__p__mbcasemap', () ),
    'msvcr71.__p__mbctype':( 'int', None, 'cdecl', 'msvcr71.__p__mbctype', () ),
    'msvcr71.__p__osver':( 'int', None, 'cdecl', 'msvcr71.__p__osver', () ),
    'msvcr71.__p__pctype':( 'int', None, 'cdecl', 'msvcr71.__p__pctype', () ),
    'msvcr71.__p__pgmptr':( 'int', None, 'cdecl', 'msvcr71.__p__pgmptr', () ),
    'msvcr71.__p__pwctype':( 'int', None, 'cdecl', 'msvcr71.__p__pwctype', () ),
    'msvcr71.__p__timezone':( 'int', None, 'cdecl', 'msvcr71.__p__timezone', () ),
    'msvcr71.__p__tzname':( 'int', None, 'cdecl', 'msvcr71.__p__tzname', () ),
    'msvcr71.__p__wcmdln':( 'int', None, 'cdecl', 'msvcr71.__p__wcmdln', () ),
    'msvcr71.__p__wenviron':( 'int', None, 'cdecl', 'msvcr71.__p__wenviron', () ),
    'msvcr71.__p__winmajor':( 'int', None, 'cdecl', 'msvcr71.__p__winmajor', () ),
    'msvcr71.__p__winminor':( 'int', None, 'cdecl', 'msvcr71.__p__winminor', () ),
    'msvcr71.__p__winver':( 'int', None, 'cdecl', 'msvcr71.__p__winver', () ),
    'msvcr71.__p__wpgmptr':( 'int', None, 'cdecl', 'msvcr71.__p__wpgmptr', () ),
    'msvcr71.__pctype_func':( 'int', None, 'cdecl', 'msvcr71.__pctype_func', () ),
    'msvcr71.__pioinfo':( 'int', None, 'cdecl', 'msvcr71.__pioinfo', () ),
    'msvcr71.__pwctype_func':( 'int', None, 'cdecl', 'msvcr71.__pwctype_func', () ),
    'msvcr71.__pxcptinfoptrs':( 'int', None, 'cdecl', 'msvcr71.__pxcptinfoptrs', () ),
    'msvcr71.__security_error_handler':( 'int', None, 'cdecl', 'msvcr71.__security_error_handler', (('int', None), ('int', None)) ),
    'msvcr71.__set_app_type':( 'int', None, 'cdecl', 'msvcr71.__set_app_type', (('int', None),) ),
    'msvcr71.__set_buffer_overrun_handler':( 'int', None, 'cdecl', 'msvcr71.__set_buffer_overrun_handler', (('int', None),) ),
    'msvcr71.__setlc_active':( 'int', None, 'cdecl', 'msvcr71.__setlc_active', () ),
    'msvcr71.__setusermatherr':( 'int', None, 'cdecl', 'msvcr71.__setusermatherr', (('int', None),) ),
    'msvcr71.__threadhandle':( 'int', None, 'stdcall', 'msvcr71.__threadhandle', () ),
    'msvcr71.__threadid':( 'int', None, 'stdcall', 'msvcr71.__threadid', () ),
    'msvcr71.__toascii':( 'int', None, 'cdecl', 'msvcr71.__toascii', (('int', None),) ),
    'msvcr71.__undname':( 'int', None, 'cdecl', 'msvcr71.__unDName', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__undnameex':( 'int', None, 'cdecl', 'msvcr71.__unDNameEx', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__uncaught_exception':( 'int', None, 'cdecl', 'msvcr71.__uncaught_exception', () ),
    'msvcr71.__unguarded_readlc_active':( 'int', None, 'cdecl', 'msvcr71.__unguarded_readlc_active', () ),
    'msvcr71.__wargv':( 'int', None, 'cdecl', 'msvcr71.__wargv', () ),
    'msvcr71.__wcserror':( 'int', None, 'cdecl', 'msvcr71.__wcserror', (('int', None),) ),
    'msvcr71.__wgetmainargs':( 'int', None, 'msfastcall', 'msvcr71.__wgetmainargs', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.__winitenv':( 'int', None, 'cdecl', 'msvcr71.__winitenv', () ),
    'msvcr71._abnormal_termination':( 'int', None, 'cdecl', 'msvcr71._abnormal_termination', () ),
    'msvcr71._access':( 'int', None, 'cdecl', 'msvcr71._access', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._acmdln':( 'int', None, 'cdecl', 'msvcr71._acmdln', () ),
    'msvcr71._adj_fdiv_m16i':( 'int', None, 'cdecl', 'msvcr71._adj_fdiv_m16i', () ),
    'msvcr71._adj_fdiv_m32':( 'int', None, 'cdecl', 'msvcr71._adj_fdiv_m32', (('int', None),) ),
    'msvcr71._adj_fdiv_m32i':( 'int', None, 'cdecl', 'msvcr71._adj_fdiv_m32i', () ),
    'msvcr71._adj_fdiv_m64':( 'int', None, 'cdecl', 'msvcr71._adj_fdiv_m64', (('int', None), ('int', None)) ),
    'msvcr71._adj_fdiv_r':( 'int', None, 'cdecl', 'msvcr71._adj_fdiv_r', () ),
    'msvcr71._adj_fdivr_m16i':( 'int', None, 'cdecl', 'msvcr71._adj_fdivr_m16i', () ),
    'msvcr71._adj_fdivr_m32':( 'int', None, 'cdecl', 'msvcr71._adj_fdivr_m32', (('int', None),) ),
    'msvcr71._adj_fdivr_m32i':( 'int', None, 'cdecl', 'msvcr71._adj_fdivr_m32i', () ),
    'msvcr71._adj_fdivr_m64':( 'int', None, 'cdecl', 'msvcr71._adj_fdivr_m64', (('int', None), ('int', None)) ),
    'msvcr71._adj_fpatan':( 'int', None, 'cdecl', 'msvcr71._adj_fpatan', () ),
    'msvcr71._adj_fprem':( 'int', None, 'cdecl', 'msvcr71._adj_fprem', () ),
    'msvcr71._adj_fprem1':( 'int', None, 'cdecl', 'msvcr71._adj_fprem1', () ),
    'msvcr71._adj_fptan':( 'int', None, 'cdecl', 'msvcr71._adj_fptan', () ),
    'msvcr71._adjust_fdiv':( 'int', None, 'cdecl', 'msvcr71._adjust_fdiv', () ),
    'msvcr71._aexit_rtn':( 'int', None, 'cdecl', 'msvcr71._aexit_rtn', () ),
    'msvcr71._aligned_free':( 'int', None, 'cdecl', 'msvcr71._aligned_free', (('int', None),) ),
    'msvcr71._aligned_malloc':( 'int', None, 'cdecl', 'msvcr71._aligned_malloc', (('int', None), ('int', None)) ),
    'msvcr71._aligned_offset_malloc':( 'int', None, 'cdecl', 'msvcr71._aligned_offset_malloc', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._aligned_offset_realloc':( 'int', None, 'cdecl', 'msvcr71._aligned_offset_realloc', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._aligned_realloc':( 'int', None, 'cdecl', 'msvcr71._aligned_realloc', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._amsg_exit':( 'int', None, 'cdecl', 'msvcr71._amsg_exit', (('int', None),) ),
    'msvcr71._assert':( 'int', None, 'stdcall', 'msvcr71._assert', (('void *', 'ptr'),) ),
    'msvcr71._atodbl':( 'int', None, 'cdecl', 'msvcr71._atodbl', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._atoi64':( 'int', None, 'cdecl', 'msvcr71._atoi64', (('int', None),) ),
    'msvcr71._atoldbl':( 'int', None, 'cdecl', 'msvcr71._atoldbl', (('int', None), ('int', None)) ),
    'msvcr71._beep':( 'int', None, 'cdecl', 'msvcr71._beep', (('int', None), ('int', None)) ),
    'msvcr71._beginthread':( 'int', None, 'cdecl', 'msvcr71._beginthread', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._beginthreadex':( 'int', None, 'cdecl', 'msvcr71._beginthreadex', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._c_exit':( 'int', None, 'cdecl', 'msvcr71._c_exit', () ),
    'msvcr71._cabs':( 'int', None, 'cdecl', 'msvcr71._cabs', () ),
    'msvcr71._callnewh':( 'int', None, 'cdecl', 'msvcr71._callnewh', (('int', None),) ),
    'msvcr71._cexit':( 'int', None, 'cdecl', 'msvcr71._cexit', () ),
    'msvcr71._cgets':( 'int', None, 'cdecl', 'msvcr71._cgets', (('int', None),) ),
    'msvcr71._cgetws':( 'int', None, 'cdecl', 'msvcr71._cgetws', (('int', None),) ),
    'msvcr71._chdir':( 'int', None, 'cdecl', 'msvcr71._chdir', (('int', None),) ),
    'msvcr71._chdrive':( 'int', None, 'cdecl', 'msvcr71._chdrive', (('int', None),) ),
    'msvcr71._chgsign':( 'int', None, 'cdecl', 'msvcr71._chgsign', (('int', None), ('int', None)) ),
    'msvcr71._chkesp':( 'int', None, 'cdecl', 'msvcr71._chkesp', () ),
    'msvcr71._chmod':( 'int', None, 'cdecl', 'msvcr71._chmod', (('int', None), ('int', None)) ),
    'msvcr71._chsize':( 'int', None, 'cdecl', 'msvcr71._chsize', (('int', None), ('int', None)) ),
    'msvcr71._clearfp':( 'int', None, 'cdecl', 'msvcr71._clearfp', () ),
    'msvcr71._close':( 'int', None, 'cdecl', 'msvcr71._close', (('int', None),) ),
    'msvcr71._commit':( 'int', None, 'cdecl', 'msvcr71._commit', (('int', None),) ),
    'msvcr71._commode':( 'int', None, 'cdecl', 'msvcr71._commode', () ),
    'msvcr71._control87':( 'int', None, 'cdecl', 'msvcr71._control87', () ),
    'msvcr71._controlfp':( 'int', None, 'cdecl', 'msvcr71._controlfp', (('int', None), ('int', None)) ),
    'msvcr71._copysign':( 'int', None, 'cdecl', 'msvcr71._copysign', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._cprintf':( 'int', None, 'cdecl', 'msvcr71._cprintf', (('int', None),) ),
    'msvcr71._cputs':( 'int', None, 'cdecl', 'msvcr71._cputs', (('void *', 'ptr'),) ),
    'msvcr71._cputws':( 'int', None, 'cdecl', 'msvcr71._cputws', (('void *', 'ptr'),) ),
    'msvcr71._creat':( 'int', None, 'cdecl', 'msvcr71._creat', (('StringA', None), ('int', None)) ),
    'msvcr71._cscanf':( 'int', None, 'cdecl', 'msvcr71._cscanf', (('int', None),) ),
    'msvcr71._ctime64':( 'int', None, 'cdecl', 'msvcr71._ctime64', (('void *', 'ptr'),) ),
    'msvcr71._cwait':( 'int', None, 'cdecl', 'msvcr71._cwait', (('void *', 'ptr'), ('HANDLE', None)) ),
    'msvcr71._cwprintf':( 'int', None, 'cdecl', 'msvcr71._cwprintf', (('int', None),) ),
    'msvcr71._cwscanf':( 'int', None, 'cdecl', 'msvcr71._cwscanf', (('int', None),) ),
    'msvcr71._daylight':( 'int', None, 'bfastcall', 'msvcr71._daylight', (('int', None),) ),
    'msvcr71._dstbias':( 'int', None, 'cdecl', 'msvcr71._dstbias', () ),
    'msvcr71._dup':( 'int', None, 'cdecl', 'msvcr71._dup', (('int', None),) ),
    'msvcr71._dup2':( 'int', None, 'cdecl', 'msvcr71._dup2', (('int', None), ('int', None)) ),
    'msvcr71._ecvt':( 'int', None, 'cdecl', 'msvcr71._ecvt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._endthread':( 'int', None, 'cdecl', 'msvcr71._endthread', () ),
    'msvcr71._endthreadex':( 'int', None, 'cdecl', 'msvcr71._endthreadex', (('int', None),) ),
    'msvcr71._environ':( 'int', None, 'cdecl', 'msvcr71._environ', () ),
    'msvcr71._eof':( 'int', None, 'cdecl', 'msvcr71._eof', (('int', None),) ),
    'msvcr71._errno':( 'int', None, 'cdecl', 'msvcr71._errno', () ),
    'msvcr71._except_handler2':( 'int', None, 'cdecl', 'msvcr71._except_handler2', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._except_handler3':( 'int', None, 'cdecl', 'msvcr71._except_handler3', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._execl':( 'int', None, 'cdecl', 'msvcr71._execl', () ),
    'msvcr71._execle':( 'int', None, 'cdecl', 'msvcr71._execle', ( ('int', None), ('int', None)) ),
    'msvcr71._execlp':( 'int', None, 'cdecl', 'msvcr71._execlp', () ),
    'msvcr71._execlpe':( 'int', None, 'cdecl', 'msvcr71._execlpe', ( ('int', None), ('int', None)) ),
    'msvcr71._execv':( 'int', None, 'cdecl', 'msvcr71._execv', ( ('int', None),) ),
    'msvcr71._execve':( 'int', None, 'cdecl', 'msvcr71._execve', ( ('int', None), ('int', None)) ),
    'msvcr71._execvp':( 'int', None, 'cdecl', 'msvcr71._execvp', ( ('int', None),) ),
    'msvcr71._execvpe':( 'int', None, 'cdecl', 'msvcr71._execvpe', ( ('int', None), ('int', None)) ),
    'msvcr71._exit':( 'int', None, 'cdecl', 'msvcr71._exit', (('int', None),) ),
    'msvcr71._expand':( 'int', None, 'cdecl', 'msvcr71._expand', (('int', None), ('int', None)) ),
    'msvcr71._fcloseall':( 'int', None, 'cdecl', 'msvcr71._fcloseall', () ),
    'msvcr71._fcvt':( 'int', None, 'cdecl', 'msvcr71._fcvt', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._fdopen':( 'int', None, 'cdecl', 'msvcr71._fdopen', (('int', None), ('int', None)) ),
    'msvcr71._fgetchar':( 'int', None, 'cdecl', 'msvcr71._fgetchar', () ),
    'msvcr71._fgetwchar':( 'int', None, 'cdecl', 'msvcr71._fgetwchar', () ),
    'msvcr71._filbuf':( 'int', None, 'cdecl', 'msvcr71._filbuf', (('int', None),) ),
    'msvcr71._fileinfo':( 'int', None, 'cdecl', 'msvcr71._fileinfo', () ),
    'msvcr71._filelength':( 'int', None, 'cdecl', 'msvcr71._filelength', (('int', None),) ),
    'msvcr71._filelengthi64':( 'int', None, 'cdecl', 'msvcr71._filelengthi64', (('int', None),) ),
    'msvcr71._fileno':( 'int', None, 'cdecl', 'msvcr71._fileno', (('int', None),) ),
    'msvcr71._findclose':( 'int', None, 'cdecl', 'msvcr71._findclose', (('void *', 'ptr'),) ),
    'msvcr71._findfirst':( 'int', None, 'cdecl', 'msvcr71._findfirst', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._findfirst64':( 'int', None, 'cdecl', 'msvcr71._findfirst64', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._findfirsti64':( 'int', None, 'cdecl', 'msvcr71._findfirsti64', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._findnext':( 'int', None, 'cdecl', 'msvcr71._findnext', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._findnext64':( 'int', None, 'cdecl', 'msvcr71._findnext64', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._findnexti64':( 'int', None, 'cdecl', 'msvcr71._findnexti64', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._finite':( 'int', None, 'cdecl', 'msvcr71._finite', (('int', None), ('int', None)) ),
    'msvcr71._flsbuf':( 'int', None, 'cdecl', 'msvcr71._flsbuf', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._flushall':( 'int', None, 'cdecl', 'msvcr71._flushall', () ),
    'msvcr71._fmode':( 'int', None, 'cdecl', 'msvcr71._fmode', () ),
    'msvcr71._fpclass':( 'int', None, 'cdecl', 'msvcr71._fpclass', (('int', None), ('int', None)) ),
    'msvcr71._fpieee_flt':( 'int', None, 'cdecl', 'msvcr71._fpieee_flt', (('int', None),) ),
    'msvcr71._fpreset':( 'int', None, 'cdecl', 'msvcr71._fpreset', () ),
    'msvcr71._fputchar':( 'int', None, 'cdecl', 'msvcr71._fputchar', (('int', None),) ),
    'msvcr71._fputwchar':( 'int', None, 'cdecl', 'msvcr71._fputwchar', (('int', None),) ),
    'msvcr71._fsopen':( 'int', None, 'cdecl', 'msvcr71._fsopen', (('StringA', None), ('int', None), ('int', None)) ),
    'msvcr71._fstat':( 'int', None, 'cdecl', 'msvcr71._fstat', (('int', None), ('int', None)) ),
    'msvcr71._fstat64':( 'int', None, 'cdecl', 'msvcr71._fstat64', (('int', None), ('int', None)) ),
    'msvcr71._fstati64':( 'int', None, 'cdecl', 'msvcr71._fstati64', (('int', None), ('int', None)) ),
    'msvcr71._ftime':( 'int', None, 'cdecl', 'msvcr71._ftime', (('int', None),) ),
    'msvcr71._ftime64':( 'int', None, 'cdecl', 'msvcr71._ftime64', (('int', None),) ),
    'msvcr71._ftol':( 'int', None, 'cdecl', 'msvcr71._ftol', () ),
    'msvcr71._fullpath':( 'int', None, 'cdecl', 'msvcr71._fullpath', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._futime':( 'int', None, 'cdecl', 'msvcr71._futime', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._futime64':( 'int', None, 'cdecl', 'msvcr71._futime64', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._gcvt':( 'int', None, 'cdecl', 'msvcr71._gcvt', (('int', None), ('int', None), ('int', None), ('void *', 'ptr')) ),
    'msvcr71._get_heap_handle':( 'int', None, 'cdecl', 'msvcr71._get_heap_handle', () ),
    'msvcr71._get_osfhandle':( 'int', None, 'cdecl', 'msvcr71._get_osfhandle', (('int', None),) ),
    'msvcr71._get_sbh_threshold':( 'int', None, 'cdecl', 'msvcr71._get_sbh_threshold', () ),
    'msvcr71._getch':( 'int', None, 'cdecl', 'msvcr71._getch', () ),
    'msvcr71._getche':( 'int', None, 'cdecl', 'msvcr71._getche', () ),
    'msvcr71._getcwd':( 'int', None, 'cdecl', 'msvcr71._getcwd', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._getdcwd':( 'int', None, 'cdecl', 'msvcr71._getdcwd', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._getdiskfree':( 'int', None, 'cdecl', 'msvcr71._getdiskfree', (('int', None), ('int', None)) ),
    'msvcr71._getdllprocaddr':( 'int', None, 'cdecl', 'msvcr71._getdllprocaddr', (('HMODULE', None), ('StringA', None), ('int', None)) ),
    'msvcr71._getdrive':( 'int', None, 'cdecl', 'msvcr71._getdrive', () ),
    'msvcr71._getdrives':( 'int', None, 'stdcall', 'msvcr71._getdrives', () ),
    'msvcr71._getmaxstdio':( 'int', None, 'cdecl', 'msvcr71._getmaxstdio', () ),
    'msvcr71._getmbcp':( 'int', None, 'cdecl', 'msvcr71._getmbcp', () ),
    'msvcr71._getpid':( 'int', None, 'stdcall', 'msvcr71._getpid', () ),
    'msvcr71._getsystime':( 'int', None, 'cdecl', 'msvcr71._getsystime', (('int', None),) ),
    'msvcr71._getw':( 'int', None, 'cdecl', 'msvcr71._getw', (('int', None),) ),
    'msvcr71._getwch':( 'int', None, 'cdecl', 'msvcr71._getwch', () ),
    'msvcr71._getwche':( 'int', None, 'cdecl', 'msvcr71._getwche', () ),
    'msvcr71._getws':( 'int', None, 'cdecl', 'msvcr71._getws', (('int', None),) ),
    'msvcr71._global_unwind2':( 'int', None, 'cdecl', 'msvcr71._global_unwind2', (('int', None),) ),
    'msvcr71._gmtime64':( 'int', None, 'cdecl', 'msvcr71._gmtime64', (('void *', 'ptr'),) ),
    'msvcr71._heapadd':( 'int', None, 'cdecl', 'msvcr71._heapadd', () ),
    'msvcr71._heapchk':( 'int', None, 'cdecl', 'msvcr71._heapchk', () ),
    'msvcr71._heapmin':( 'int', None, 'cdecl', 'msvcr71._heapmin', () ),
    'msvcr71._heapset':( 'int', None, 'cdecl', 'msvcr71._heapset', () ),
    'msvcr71._heapused':( 'int', None, 'cdecl', 'msvcr71._heapused', () ),
    'msvcr71._heapwalk':( 'int', None, 'cdecl', 'msvcr71._heapwalk', (('int', None),) ),
    'msvcr71._hypot':( 'int', None, 'cdecl', 'msvcr71._hypot', () ),
    'msvcr71._i64toa':( 'int', None, 'msfastcall', 'msvcr71._i64toa', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._i64tow':( 'int', None, 'msfastcall', 'msvcr71._i64tow', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._initterm':( 'int', None, 'cdecl', 'msvcr71._initterm', (('int', None), ('int', None)) ),
    'msvcr71._inp':( 'int', None, 'cdecl', 'msvcr71._inp', (('int', None),) ),
    'msvcr71._inpd':( 'int', None, 'cdecl', 'msvcr71._inpd', (('int', None),) ),
    'msvcr71._inpw':( 'int', None, 'cdecl', 'msvcr71._inpw', (('int', None),) ),
    'msvcr71._iob':( 'int', None, 'bfastcall', 'msvcr71._iob', (('int', None),) ),
    'msvcr71._isatty':( 'int', None, 'cdecl', 'msvcr71._isatty', (('int', None),) ),
    'msvcr71._isctype':( 'int', None, 'cdecl', 'msvcr71._isctype', (('int', None), ('int', None)) ),
    'msvcr71._ismbbalnum':( 'int', None, 'cdecl', 'msvcr71._ismbbalnum', (('int', None),) ),
    'msvcr71._ismbbalpha':( 'int', None, 'cdecl', 'msvcr71._ismbbalpha', (('int', None),) ),
    'msvcr71._ismbbgraph':( 'int', None, 'cdecl', 'msvcr71._ismbbgraph', (('int', None),) ),
    'msvcr71._ismbbkalnum':( 'int', None, 'cdecl', 'msvcr71._ismbbkalnum', (('int', None),) ),
    'msvcr71._ismbbkana':( 'int', None, 'cdecl', 'msvcr71._ismbbkana', (('int', None),) ),
    'msvcr71._ismbbkprint':( 'int', None, 'cdecl', 'msvcr71._ismbbkprint', (('int', None),) ),
    'msvcr71._ismbbkpunct':( 'int', None, 'cdecl', 'msvcr71._ismbbkpunct', (('int', None),) ),
    'msvcr71._ismbblead':( 'int', None, 'cdecl', 'msvcr71._ismbblead', (('int', None),) ),
    'msvcr71._ismbbprint':( 'int', None, 'cdecl', 'msvcr71._ismbbprint', (('int', None),) ),
    'msvcr71._ismbbpunct':( 'int', None, 'cdecl', 'msvcr71._ismbbpunct', (('int', None),) ),
    'msvcr71._ismbbtrail':( 'int', None, 'cdecl', 'msvcr71._ismbbtrail', (('int', None),) ),
    'msvcr71._ismbcalnum':( 'int', None, 'cdecl', 'msvcr71._ismbcalnum', (('int', None),) ),
    'msvcr71._ismbcalpha':( 'int', None, 'cdecl', 'msvcr71._ismbcalpha', (('int', None),) ),
    'msvcr71._ismbcdigit':( 'int', None, 'cdecl', 'msvcr71._ismbcdigit', (('int', None),) ),
    'msvcr71._ismbcgraph':( 'int', None, 'cdecl', 'msvcr71._ismbcgraph', (('int', None),) ),
    'msvcr71._ismbchira':( 'int', None, 'cdecl', 'msvcr71._ismbchira', (('int', None),) ),
    'msvcr71._ismbckata':( 'int', None, 'cdecl', 'msvcr71._ismbckata', (('int', None),) ),
    'msvcr71._ismbcl0':( 'int', None, 'cdecl', 'msvcr71._ismbcl0', (('int', None),) ),
    'msvcr71._ismbcl1':( 'int', None, 'cdecl', 'msvcr71._ismbcl1', (('int', None),) ),
    'msvcr71._ismbcl2':( 'int', None, 'cdecl', 'msvcr71._ismbcl2', (('int', None),) ),
    'msvcr71._ismbclegal':( 'int', None, 'cdecl', 'msvcr71._ismbclegal', (('int', None),) ),
    'msvcr71._ismbclower':( 'int', None, 'cdecl', 'msvcr71._ismbclower', (('int', None),) ),
    'msvcr71._ismbcprint':( 'int', None, 'cdecl', 'msvcr71._ismbcprint', (('int', None),) ),
    'msvcr71._ismbcpunct':( 'int', None, 'cdecl', 'msvcr71._ismbcpunct', (('int', None),) ),
    'msvcr71._ismbcspace':( 'int', None, 'cdecl', 'msvcr71._ismbcspace', (('int', None),) ),
    'msvcr71._ismbcsymbol':( 'int', None, 'cdecl', 'msvcr71._ismbcsymbol', (('int', None),) ),
    'msvcr71._ismbcupper':( 'int', None, 'cdecl', 'msvcr71._ismbcupper', (('int', None),) ),
    'msvcr71._ismbslead':( 'int', None, 'cdecl', 'msvcr71._ismbslead', (('int', None), ('int', None)) ),
    'msvcr71._ismbstrail':( 'int', None, 'cdecl', 'msvcr71._ismbstrail', (('int', None), ('int', None)) ),
    'msvcr71._isnan':( 'int', None, 'cdecl', 'msvcr71._isnan', (('int', None), ('int', None)) ),
    'msvcr71._itoa':( 'int', None, 'cdecl', 'msvcr71._itoa', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'msvcr71._itow':( 'int', None, 'cdecl', 'msvcr71._itow', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._j0':( 'int', None, 'cdecl', 'msvcr71._j0', () ),
    'msvcr71._j1':( 'int', None, 'cdecl', 'msvcr71._j1', () ),
    'msvcr71._jn':( 'int', None, 'cdecl', 'msvcr71._jn', (('int', None),) ),
    'msvcr71._kbhit':( 'int', None, 'cdecl', 'msvcr71._kbhit', () ),
    'msvcr71._lfind':( 'int', None, 'cdecl', 'msvcr71._lfind', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'funcptr')) ),
    'msvcr71._loaddll':( 'int', None, 'cdecl', 'msvcr71._loaddll', (('FileNameA', None),) ),
    'msvcr71._local_unwind2':( 'int', None, 'cdecl', 'msvcr71._local_unwind2', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._localtime64':( 'int', None, 'cdecl', 'msvcr71._localtime64', (('void *', 'ptr'),) ),
    'msvcr71._lock':( 'int', None, 'cdecl', 'msvcr71._lock', (('int', None),) ),
    'msvcr71._locking':( 'int', None, 'cdecl', 'msvcr71._locking', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._logb':( 'int', None, 'cdecl', 'msvcr71._logb', (('int', None), ('int', None)) ),
    'msvcr71._longjmpex':( 'int', None, 'cdecl', 'msvcr71._longjmpex', (('int', None), ('int', None)) ),
    'msvcr71._lrotl':( 'int', None, 'cdecl', 'msvcr71._lrotl', (('int', None), ('int', None)) ),
    'msvcr71._lrotr':( 'int', None, 'cdecl', 'msvcr71._lrotr', (('int', None), ('int', None)) ),
    'msvcr71._lsearch':( 'int', None, 'cdecl', 'msvcr71._lsearch', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None), ('int', None), ('void *', 'funcptr')) ),
    'msvcr71._lseek':( 'int', None, 'cdecl', 'msvcr71._lseek', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._lseeki64':( 'int', None, 'cdecl', 'msvcr71._lseeki64', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._ltoa':( 'int', None, 'cdecl', 'msvcr71._ltoa', (('int', None), ('void *', 'obj'), ('int', None)) ),
    'msvcr71._ltow':( 'int', None, 'cdecl', 'msvcr71._ltow', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._makepath':( 'int', None, 'cdecl', 'msvcr71._makepath', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbbtombc':( 'int', None, 'cdecl', 'msvcr71._mbbtombc', (('int', None),) ),
    'msvcr71._mbbtype':( 'int', None, 'cdecl', 'msvcr71._mbbtype', (('int', None), ('int', None)) ),
    'msvcr71._mbcasemap':( 'int', None, 'cdecl', 'msvcr71._mbcasemap', () ),
    'msvcr71._mbccpy':( 'int', None, 'cdecl', 'msvcr71._mbccpy', (('int', None), ('int', None)) ),
    'msvcr71._mbcjistojms':( 'int', None, 'cdecl', 'msvcr71._mbcjistojms', (('int', None),) ),
    'msvcr71._mbcjmstojis':( 'int', None, 'cdecl', 'msvcr71._mbcjmstojis', (('int', None),) ),
    'msvcr71._mbclen':( 'int', None, 'cdecl', 'msvcr71._mbclen', (('int', None),) ),
    'msvcr71._mbctohira':( 'int', None, 'cdecl', 'msvcr71._mbctohira', (('int', None),) ),
    'msvcr71._mbctokata':( 'int', None, 'cdecl', 'msvcr71._mbctokata', (('int', None),) ),
    'msvcr71._mbctolower':( 'int', None, 'cdecl', 'msvcr71._mbctolower', (('int', None),) ),
    'msvcr71._mbctombb':( 'int', None, 'cdecl', 'msvcr71._mbctombb', (('int', None),) ),
    'msvcr71._mbctoupper':( 'int', None, 'cdecl', 'msvcr71._mbctoupper', (('int', None),) ),
    'msvcr71._mbctype':( 'int', None, 'cdecl', 'msvcr71._mbctype', () ),
    'msvcr71._mbsbtype':( 'int', None, 'cdecl', 'msvcr71._mbsbtype', (('int', None), ('int', None)) ),
    'msvcr71._mbscat':( 'int', None, 'cdecl', 'msvcr71._mbscat', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbschr':( 'int', None, 'cdecl', 'msvcr71._mbschr', (('int', None), ('int', None)) ),
    'msvcr71._mbscmp':( 'int', None, 'cdecl', 'msvcr71._mbscmp', (('int', None), ('int', None)) ),
    'msvcr71._mbscoll':( 'int', None, 'cdecl', 'msvcr71._mbscoll', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbscpy':( 'int', None, 'cdecl', 'msvcr71._mbscpy', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbscspn':( 'int', None, 'cdecl', 'msvcr71._mbscspn', (('int', None), ('int', None)) ),
    'msvcr71._mbsdec':( 'int', None, 'cdecl', 'msvcr71._mbsdec', (('int', None), ('int', None)) ),
    'msvcr71._mbsdup':( 'int', None, 'cdecl', 'msvcr71._mbsdup', (('void *', 'ptr'),) ),
    'msvcr71._mbsicmp':( 'int', None, 'cdecl', 'msvcr71._mbsicmp', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbsicoll':( 'int', None, 'cdecl', 'msvcr71._mbsicoll', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbsinc':( 'int', None, 'cdecl', 'msvcr71._mbsinc', (('int', None),) ),
    'msvcr71._mbslen':( 'int', None, 'cdecl', 'msvcr71._mbslen', (('int', None),) ),
    'msvcr71._mbslwr':( 'int', None, 'cdecl', 'msvcr71._mbslwr', (('void *', 'ptr'),) ),
    'msvcr71._mbsnbcat':( 'int', None, 'cdecl', 'msvcr71._mbsnbcat', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsnbcmp':( 'int', None, 'cdecl', 'msvcr71._mbsnbcmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsnbcnt':( 'int', None, 'cdecl', 'msvcr71._mbsnbcnt', (('int', None), ('int', None)) ),
    'msvcr71._mbsnbcoll':( 'int', None, 'cdecl', 'msvcr71._mbsnbcoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsnbcpy':( 'int', None, 'cdecl', 'msvcr71._mbsnbcpy', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsnbicmp':( 'int', None, 'cdecl', 'msvcr71._mbsnbicmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsnbicoll':( 'int', None, 'cdecl', 'msvcr71._mbsnbicoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsnbset':( 'int', None, 'cdecl', 'msvcr71._mbsnbset', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsncat':( 'int', None, 'cdecl', 'msvcr71._mbsncat', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._mbsnccnt':( 'int', None, 'cdecl', 'msvcr71._mbsnccnt', (('int', None), ('int', None)) ),
    'msvcr71._mbsncmp':( 'int', None, 'cdecl', 'msvcr71._mbsncmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsncoll':( 'int', None, 'cdecl', 'msvcr71._mbsncoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsncpy':( 'int', None, 'cdecl', 'msvcr71._mbsncpy', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsnextc':( 'int', None, 'cdecl', 'msvcr71._mbsnextc', (('int', None),) ),
    'msvcr71._mbsnicmp':( 'int', None, 'cdecl', 'msvcr71._mbsnicmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbsnicoll':( 'int', None, 'cdecl', 'msvcr71._mbsnicoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._mbsninc':( 'int', None, 'cdecl', 'msvcr71._mbsninc', (('int', None), ('int', None)) ),
    'msvcr71._mbsnset':( 'int', None, 'cdecl', 'msvcr71._mbsnset', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mbspbrk':( 'int', None, 'cdecl', 'msvcr71._mbspbrk', (('int', None), ('int', None)) ),
    'msvcr71._mbsrchr':( 'int', None, 'cdecl', 'msvcr71._mbsrchr', (('int', None), ('int', None)) ),
    'msvcr71._mbsrev':( 'int', None, 'cdecl', 'msvcr71._mbsrev', (('int', None),) ),
    'msvcr71._mbsset':( 'int', None, 'cdecl', 'msvcr71._mbsset', (('int', None), ('int', None)) ),
    'msvcr71._mbsspn':( 'int', None, 'cdecl', 'msvcr71._mbsspn', (('int', None), ('int', None)) ),
    'msvcr71._mbsspnp':( 'int', None, 'cdecl', 'msvcr71._mbsspnp', (('int', None), ('int', None)) ),
    'msvcr71._mbsstr':( 'int', None, 'cdecl', 'msvcr71._mbsstr', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._mbstok':( 'int', None, 'cdecl', 'msvcr71._mbstok', (('int', None), ('int', None)) ),
    'msvcr71._mbstrlen':( 'int', None, 'cdecl', 'msvcr71._mbstrlen', (('int', None),) ),
    'msvcr71._mbsupr':( 'int', None, 'cdecl', 'msvcr71._mbsupr', (('void *', 'ptr'),) ),
    'msvcr71._memccpy':( 'int', None, 'cdecl', 'msvcr71._memccpy', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._memicmp':( 'int', None, 'cdecl', 'msvcr71._memicmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._mkdir':( 'int', None, 'cdecl', 'msvcr71._mkdir', (('StringA', None),) ),
    'msvcr71._mktemp':( 'int', None, 'cdecl', 'msvcr71._mktemp', (('void *', 'ptr'),) ),
    'msvcr71._mktime64':( 'int', None, 'cdecl', 'msvcr71._mktime64', (('int', None),) ),
    'msvcr71._msize':( 'int', None, 'cdecl', 'msvcr71._msize', (('int', None),) ),
    'msvcr71._nextafter':( 'int', None, 'cdecl', 'msvcr71._nextafter', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._onexit':( 'int', None, 'cdecl', 'msvcr71._onexit', (('int', None),) ),
    'msvcr71._open':( 'int', None, 'cdecl', 'msvcr71._open', (('StringA', None), ('int', None), ('int', None)) ),
    'msvcr71._open_osfhandle':( 'int', None, 'cdecl', 'msvcr71._open_osfhandle', (('int', None), ('int', None)) ),
    'msvcr71._osplatform':( 'int', None, 'cdecl', 'msvcr71._osplatform', () ),
    'msvcr71._osver':( 'int', None, 'cdecl', 'msvcr71._osver', () ),
    'msvcr71._outp':( 'int', None, 'cdecl', 'msvcr71._outp', (('int', None), ('int', None)) ),
    'msvcr71._outpd':( 'int', None, 'cdecl', 'msvcr71._outpd', (('int', None), ('int', None)) ),
    'msvcr71._outpw':( 'int', None, 'cdecl', 'msvcr71._outpw', (('int', None), ('int', None)) ),
    'msvcr71._pclose':( 'int', None, 'cdecl', 'msvcr71._pclose', (('int', None),) ),
    'msvcr71._pctype':( 'int', None, 'cdecl', 'msvcr71._pctype', () ),
    'msvcr71._pgmptr':( 'int', None, 'cdecl', 'msvcr71._pgmptr', () ),
    'msvcr71._pipe':( 'int', None, 'cdecl', 'msvcr71._pipe', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._popen':( 'int', None, 'cdecl', 'msvcr71._popen', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._purecall':( 'int', None, 'cdecl', 'msvcr71._purecall', () ),
    'msvcr71._putch':( 'int', None, 'cdecl', 'msvcr71._putch', (('int', None),) ),
    'msvcr71._putenv':( 'int', None, 'cdecl', 'msvcr71._putenv', (('void *', 'ptr'),) ),
    'msvcr71._putw':( 'int', None, 'cdecl', 'msvcr71._putw', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._putwch':( 'int', None, 'cdecl', 'msvcr71._putwch', (('int', None),) ),
    'msvcr71._putws':( 'int', None, 'cdecl', 'msvcr71._putws', (('int', None),) ),
    'msvcr71._pwctype':( 'int', None, 'cdecl', 'msvcr71._pwctype', () ),
    'msvcr71._read':( 'int', None, 'cdecl', 'msvcr71._read', (('int', None), ('StringA', None), ('DWORD', None)) ),
    'msvcr71._resetstkoflw':( 'int', None, 'cdecl', 'msvcr71._resetstkoflw', () ),
    'msvcr71._rmdir':( 'int', None, 'cdecl', 'msvcr71._rmdir', (('int', None),) ),
    'msvcr71._rmtmp':( 'int', None, 'cdecl', 'msvcr71._rmtmp', () ),
    'msvcr71._rotl':( 'int', None, 'cdecl', 'msvcr71._rotl', (('int', None), ('int', None)) ),
    'msvcr71._rotr':( 'int', None, 'cdecl', 'msvcr71._rotr', (('int', None), ('int', None)) ),
    'msvcr71._safe_fdiv':( 'int', None, 'cdecl', 'msvcr71._safe_fdiv', () ),
    'msvcr71._safe_fdivr':( 'int', None, 'cdecl', 'msvcr71._safe_fdivr', () ),
    'msvcr71._safe_fprem':( 'int', None, 'cdecl', 'msvcr71._safe_fprem', () ),
    'msvcr71._safe_fprem1':( 'int', None, 'cdecl', 'msvcr71._safe_fprem1', () ),
    'msvcr71._scalb':( 'int', None, 'cdecl', 'msvcr71._scalb', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._scprintf':( 'int', None, 'cdecl', 'msvcr71._scprintf', (('int', None),) ),
    'msvcr71._scwprintf':( 'int', None, 'cdecl', 'msvcr71._scwprintf', (('int', None),) ),
    'msvcr71._searchenv':( 'int', None, 'cdecl', 'msvcr71._searchenv', (('void *', 'ptr'), ('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._seh_longjmp_unwind':( 'int', None, 'stdcall', 'msvcr71._seh_longjmp_unwind', (('int', None),) ),
    'msvcr71._set_sse2_enable':( 'int', None, 'cdecl', 'msvcr71._set_SSE2_enable', (('int', None),) ),
    'msvcr71._set_error_mode':( 'int', None, 'cdecl', 'msvcr71._set_error_mode', (('int', None),) ),
    'msvcr71._set_purecall_handler':( 'int', None, 'cdecl', 'msvcr71._set_purecall_handler', (('int', None),) ),
    'msvcr71._set_sbh_threshold':( 'int', None, 'cdecl', 'msvcr71._set_sbh_threshold', (('int', None),) ),
    'msvcr71._set_security_error_handler':( 'int', None, 'cdecl', 'msvcr71._set_security_error_handler', (('int', None),) ),
    'msvcr71._seterrormode':( 'int', None, 'cdecl', 'msvcr71._seterrormode', (('int', None),) ),
    'msvcr71._setjmp':( 'int', None, 'cdecl', 'msvcr71._setjmp', (('int', None),) ),
    'msvcr71._setjmp3':( 'int', None, 'cdecl', 'msvcr71._setjmp3', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._setmaxstdio':( 'int', None, 'cdecl', 'msvcr71._setmaxstdio', (('int', None),) ),
    'msvcr71._setmbcp':( 'int', None, 'cdecl', 'msvcr71._setmbcp', (('int', None),) ),
    'msvcr71._setmode':( 'int', None, 'cdecl', 'msvcr71._setmode', (('int', None), ('int', None)) ),
    'msvcr71._setsystime':( 'int', None, 'cdecl', 'msvcr71._setsystime', (('int', None), ('int', None)) ),
    'msvcr71._sleep':( 'int', None, 'cdecl', 'msvcr71._sleep', (('int', None),) ),
    'msvcr71._snprintf':( 'int', None, 'cdecl', 'msvcr71._snprintf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._snscanf':( 'int', None, 'cdecl', 'msvcr71._snscanf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._snwprintf':( 'int', None, 'cdecl', 'msvcr71._snwprintf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._snwscanf':( 'int', None, 'cdecl', 'msvcr71._snwscanf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._sopen':( 'int', None, 'cdecl', 'msvcr71._sopen', (('StringA', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._spawnl':( 'int', None, 'cdecl', 'msvcr71._spawnl', (('int', None), ('void *', 'obj')) ),
    'msvcr71._spawnle':( 'int', None, 'cdecl', 'msvcr71._spawnle', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'msvcr71._spawnlp':( 'int', None, 'cdecl', 'msvcr71._spawnlp', (('int', None), ('void *', 'obj')) ),
    'msvcr71._spawnlpe':( 'int', None, 'cdecl', 'msvcr71._spawnlpe', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'msvcr71._spawnv':( 'int', None, 'cdecl', 'msvcr71._spawnv', (('int', None), ('void *', 'obj'), ('void *', 'ptr')) ),
    'msvcr71._spawnve':( 'int', None, 'cdecl', 'msvcr71._spawnve', (('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._spawnvp':( 'int', None, 'cdecl', 'msvcr71._spawnvp', (('int', None), ('void *', 'obj'), ('void *', 'ptr')) ),
    'msvcr71._spawnvpe':( 'int', None, 'cdecl', 'msvcr71._spawnvpe', (('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._splitpath':( 'int', None, 'cdecl', 'msvcr71._splitpath', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._stat':( 'int', None, 'cdecl', 'msvcr71._stat', (('int', None), ('int', None)) ),
    'msvcr71._stat64':( 'int', None, 'cdecl', 'msvcr71._stat64', (('int', None), ('int', None)) ),
    'msvcr71._stati64':( 'int', None, 'cdecl', 'msvcr71._stati64', (('int', None), ('int', None)) ),
    'msvcr71._statusfp':( 'int', None, 'cdecl', 'msvcr71._statusfp', () ),
    'msvcr71._strcmpi':( 'int', None, 'cdecl', 'msvcr71._strcmpi', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._strdate':( 'int', None, 'cdecl', 'msvcr71._strdate', (('int', None),) ),
    'msvcr71._strdup':( 'int', None, 'cdecl', 'msvcr71._strdup', (('void *', 'ptr'),) ),
    'msvcr71._strerror':( 'int', None, 'cdecl', 'msvcr71._strerror', (('int', None),) ),
    'msvcr71._stricmp':( 'int', None, 'cdecl', 'msvcr71._stricmp', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._stricoll':( 'int', None, 'cdecl', 'msvcr71._stricoll', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._strlwr':( 'int', None, 'cdecl', 'msvcr71._strlwr', (('void *', 'ptr'),) ),
    'msvcr71._strncoll':( 'int', None, 'cdecl', 'msvcr71._strncoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._strnicmp':( 'int', None, 'cdecl', 'msvcr71._strnicmp', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._strnicoll':( 'int', None, 'cdecl', 'msvcr71._strnicoll', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._strnset':( 'int', None, 'cdecl', 'msvcr71._strnset', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._strrev':( 'int', None, 'cdecl', 'msvcr71._strrev', (('int', None),) ),
    'msvcr71._strset':( 'int', None, 'cdecl', 'msvcr71._strset', (('int', None), ('int', None)) ),
    'msvcr71._strtime':( 'int', None, 'cdecl', 'msvcr71._strtime', (('int', None),) ),
    'msvcr71._strtoi64':( 'int', None, 'cdecl', 'msvcr71._strtoi64', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._strtoui64':( 'int', None, 'cdecl', 'msvcr71._strtoui64', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._strupr':( 'int', None, 'cdecl', 'msvcr71._strupr', (('void *', 'ptr'),) ),
    'msvcr71._swab':( 'int', None, 'cdecl', 'msvcr71._swab', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._sys_errlist':( 'int', None, 'cdecl', 'msvcr71._sys_errlist', () ),
    'msvcr71._sys_nerr':( 'int', None, 'bfastcall', 'msvcr71._sys_nerr', (('int', None),) ),
    'msvcr71._tell':( 'int', None, 'cdecl', 'msvcr71._tell', (('int', None),) ),
    'msvcr71._telli64':( 'int', None, 'cdecl', 'msvcr71._telli64', (('int', None),) ),
    'msvcr71._tempnam':( 'int', None, 'cdecl', 'msvcr71._tempnam', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._time64':( 'int', None, 'cdecl', 'msvcr71._time64', (('void *', 'ptr'),) ),
    'msvcr71._timezone':( 'int', None, 'bfastcall', 'msvcr71._timezone', (('int', None),) ),
    'msvcr71._tolower':( 'int', None, 'cdecl', 'msvcr71._tolower', (('int', None),) ),
    'msvcr71._toupper':( 'int', None, 'cdecl', 'msvcr71._toupper', (('int', None),) ),
    'msvcr71._tzname':( 'int', None, 'cdecl', 'msvcr71._tzname', () ),
    'msvcr71._tzset':( 'int', None, 'cdecl', 'msvcr71._tzset', () ),
    'msvcr71._ui64toa':( 'int', None, 'msfastcall', 'msvcr71._ui64toa', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._ui64tow':( 'int', None, 'msfastcall', 'msvcr71._ui64tow', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._ultoa':( 'int', None, 'cdecl', 'msvcr71._ultoa', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'msvcr71._ultow':( 'int', None, 'cdecl', 'msvcr71._ultow', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._umask':( 'int', None, 'cdecl', 'msvcr71._umask', (('int', None),) ),
    'msvcr71._ungetch':( 'int', None, 'cdecl', 'msvcr71._ungetch', (('int', None),) ),
    'msvcr71._ungetwch':( 'int', None, 'cdecl', 'msvcr71._ungetwch', (('int', None),) ),
    'msvcr71._unlink':( 'int', None, 'cdecl', 'msvcr71._unlink', (('int', None),) ),
    'msvcr71._unloaddll':( 'int', None, 'cdecl', 'msvcr71._unloaddll', (('int', None),) ),
    'msvcr71._unlock':( 'int', None, 'cdecl', 'msvcr71._unlock', (('int', None),) ),
    'msvcr71._utime':( 'int', None, 'cdecl', 'msvcr71._utime', (('StringA', None), ('void *', 'ptr')) ),
    'msvcr71._utime64':( 'int', None, 'cdecl', 'msvcr71._utime64', (('StringA', None), ('void *', 'ptr')) ),
    'msvcr71._vscprintf':( 'int', None, 'cdecl', 'msvcr71._vscprintf', (('int', None), ('int', None)) ),
    'msvcr71._vscwprintf':( 'int', None, 'cdecl', 'msvcr71._vscwprintf', (('int', None), ('int', None)) ),
    'msvcr71._vsnprintf':( 'int', None, 'cdecl', 'msvcr71._vsnprintf', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._vsnwprintf':( 'int', None, 'cdecl', 'msvcr71._vsnwprintf', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._waccess':( 'int', None, 'cdecl', 'msvcr71._waccess', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._wasctime':( 'int', None, 'cdecl', 'msvcr71._wasctime', (('int', None),) ),
    'msvcr71._wchdir':( 'int', None, 'cdecl', 'msvcr71._wchdir', (('int', None),) ),
    'msvcr71._wchmod':( 'int', None, 'cdecl', 'msvcr71._wchmod', (('int', None), ('int', None)) ),
    'msvcr71._wcmdln':( 'int', None, 'cdecl', 'msvcr71._wcmdln', () ),
    'msvcr71._wcreat':( 'int', None, 'cdecl', 'msvcr71._wcreat', (('StringW', None), ('int', None)) ),
    'msvcr71._wcsdup':( 'int', None, 'cdecl', 'msvcr71._wcsdup', (('int', None),) ),
    'msvcr71._wcserror':( 'int', None, 'cdecl', 'msvcr71._wcserror', (('int', None),) ),
    'msvcr71._wcsicmp':( 'int', None, 'cdecl', 'msvcr71._wcsicmp', (('int', None), ('int', None)) ),
    'msvcr71._wcsicoll':( 'int', None, 'cdecl', 'msvcr71._wcsicoll', (('int', None), ('int', None)) ),
    'msvcr71._wcslwr':( 'int', None, 'cdecl', 'msvcr71._wcslwr', (('int', None),) ),
    'msvcr71._wcsncoll':( 'int', None, 'cdecl', 'msvcr71._wcsncoll', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcsnicmp':( 'int', None, 'cdecl', 'msvcr71._wcsnicmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcsnicoll':( 'int', None, 'cdecl', 'msvcr71._wcsnicoll', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcsnset':( 'int', None, 'cdecl', 'msvcr71._wcsnset', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcsrev':( 'int', None, 'cdecl', 'msvcr71._wcsrev', (('int', None),) ),
    'msvcr71._wcsset':( 'int', None, 'cdecl', 'msvcr71._wcsset', (('int', None), ('int', None)) ),
    'msvcr71._wcstoi64':( 'int', None, 'cdecl', 'msvcr71._wcstoi64', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcstoui64':( 'int', None, 'cdecl', 'msvcr71._wcstoui64', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wcsupr':( 'int', None, 'cdecl', 'msvcr71._wcsupr', (('int', None),) ),
    'msvcr71._wctime':( 'int', None, 'cdecl', 'msvcr71._wctime', (('void *', 'ptr'),) ),
    'msvcr71._wctime64':( 'int', None, 'cdecl', 'msvcr71._wctime64', (('void *', 'ptr'),) ),
    'msvcr71._wctype':( 'int', None, 'cdecl', 'msvcr71._wctype', () ),
    'msvcr71._wenviron':( 'int', None, 'cdecl', 'msvcr71._wenviron', () ),
    'msvcr71._wexecl':( 'int', None, 'cdecl', 'msvcr71._wexecl', () ),
    'msvcr71._wexecle':( 'int', None, 'cdecl', 'msvcr71._wexecle', ( ('int', None), ('int', None)) ),
    'msvcr71._wexeclp':( 'int', None, 'cdecl', 'msvcr71._wexeclp', () ),
    'msvcr71._wexeclpe':( 'int', None, 'cdecl', 'msvcr71._wexeclpe', ( ('int', None), ('int', None)) ),
    'msvcr71._wexecv':( 'int', None, 'cdecl', 'msvcr71._wexecv', ( ('int', None),) ),
    'msvcr71._wexecve':( 'int', None, 'cdecl', 'msvcr71._wexecve', ( ('int', None), ('int', None)) ),
    'msvcr71._wexecvp':( 'int', None, 'cdecl', 'msvcr71._wexecvp', ( ('int', None),) ),
    'msvcr71._wexecvpe':( 'int', None, 'cdecl', 'msvcr71._wexecvpe', ( ('int', None), ('int', None)) ),
    'msvcr71._wfdopen':( 'int', None, 'cdecl', 'msvcr71._wfdopen', (('int', None), ('int', None)) ),
    'msvcr71._wfindfirst':( 'int', None, 'cdecl', 'msvcr71._wfindfirst', (('int', None), ('int', None)) ),
    'msvcr71._wfindfirst64':( 'int', None, 'cdecl', 'msvcr71._wfindfirst64', (('int', None), ('int', None)) ),
    'msvcr71._wfindfirsti64':( 'int', None, 'cdecl', 'msvcr71._wfindfirsti64', (('int', None), ('int', None)) ),
    'msvcr71._wfindnext':( 'int', None, 'cdecl', 'msvcr71._wfindnext', (('int', None), ('int', None)) ),
    'msvcr71._wfindnext64':( 'int', None, 'cdecl', 'msvcr71._wfindnext64', (('int', None), ('int', None)) ),
    'msvcr71._wfindnexti64':( 'int', None, 'cdecl', 'msvcr71._wfindnexti64', (('int', None), ('int', None)) ),
    'msvcr71._wfopen':( 'int', None, 'cdecl', 'msvcr71._wfopen', (('StringW', None), ('int', None)) ),
    'msvcr71._wfreopen':( 'int', None, 'cdecl', 'msvcr71._wfreopen', (('StringW', None), ('int', None), ('int', None)) ),
    'msvcr71._wfsopen':( 'int', None, 'cdecl', 'msvcr71._wfsopen', (('StringW', None), ('int', None), ('int', None)) ),
    'msvcr71._wfullpath':( 'int', None, 'cdecl', 'msvcr71._wfullpath', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71._wgetcwd':( 'int', None, 'cdecl', 'msvcr71._wgetcwd', (('int', None), ('int', None)) ),
    'msvcr71._wgetdcwd':( 'int', None, 'cdecl', 'msvcr71._wgetdcwd', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wgetenv':( 'int', None, 'cdecl', 'msvcr71._wgetenv', (('int', None),) ),
    'msvcr71._winmajor':( 'int', None, 'cdecl', 'msvcr71._winmajor', () ),
    'msvcr71._winminor':( 'int', None, 'cdecl', 'msvcr71._winminor', () ),
    'msvcr71._winver':( 'int', None, 'cdecl', 'msvcr71._winver', () ),
    'msvcr71._wmakepath':( 'int', None, 'cdecl', 'msvcr71._wmakepath', (('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wmkdir':( 'int', None, 'cdecl', 'msvcr71._wmkdir', (('StringW', None),) ),
    'msvcr71._wmktemp':( 'int', None, 'cdecl', 'msvcr71._wmktemp', (('void *', 'ptr'),) ),
    'msvcr71._wopen':( 'int', None, 'cdecl', 'msvcr71._wopen', (('StringW', None), ('int', None), ('int', None)) ),
    'msvcr71._wperror':( 'int', None, 'cdecl', 'msvcr71._wperror', (('void *', 'ptr'),) ),
    'msvcr71._wpgmptr':( 'int', None, 'cdecl', 'msvcr71._wpgmptr', () ),
    'msvcr71._wpopen':( 'int', None, 'cdecl', 'msvcr71._wpopen', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71._wputenv':( 'int', None, 'cdecl', 'msvcr71._wputenv', (('void *', 'ptr'),) ),
    'msvcr71._wremove':( 'int', None, 'cdecl', 'msvcr71._wremove', (('int', None),) ),
    'msvcr71._wrename':( 'int', None, 'cdecl', 'msvcr71._wrename', (('int', None), ('int', None)) ),
    'msvcr71._write':( 'int', None, 'cdecl', 'msvcr71._write', (('int', None), ('void *', 'ptr'), ('DWORD', None)) ),
    'msvcr71._wrmdir':( 'int', None, 'cdecl', 'msvcr71._wrmdir', (('int', None),) ),
    'msvcr71._wsearchenv':( 'int', None, 'cdecl', 'msvcr71._wsearchenv', (('void *', 'ptr'), ('int', None), ('void *', 'ptr')) ),
    'msvcr71._wsetlocale':( 'int', None, 'cdecl', 'msvcr71._wsetlocale', (('int', None), ('void *', 'ptr')) ),
    'msvcr71._wsopen':( 'int', None, 'cdecl', 'msvcr71._wsopen', (('StringW', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wspawnl':( 'int', None, 'cdecl', 'msvcr71._wspawnl', (('int', None), ('void *', 'obj')) ),
    'msvcr71._wspawnle':( 'int', None, 'cdecl', 'msvcr71._wspawnle', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'msvcr71._wspawnlp':( 'int', None, 'cdecl', 'msvcr71._wspawnlp', (('int', None), ('void *', 'obj')) ),
    'msvcr71._wspawnlpe':( 'int', None, 'cdecl', 'msvcr71._wspawnlpe', (('int', None), ('void *', 'obj'), ('int', None), ('int', None)) ),
    'msvcr71._wspawnv':( 'int', None, 'cdecl', 'msvcr71._wspawnv', (('int', None), ('void *', 'obj'), ('void *', 'ptr')) ),
    'msvcr71._wspawnve':( 'int', None, 'cdecl', 'msvcr71._wspawnve', (('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._wspawnvp':( 'int', None, 'cdecl', 'msvcr71._wspawnvp', (('int', None), ('void *', 'obj'), ('void *', 'ptr')) ),
    'msvcr71._wspawnvpe':( 'int', None, 'cdecl', 'msvcr71._wspawnvpe', (('int', None), ('void *', 'obj'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71._wsplitpath':( 'int', None, 'cdecl', 'msvcr71._wsplitpath', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71._wstat':( 'int', None, 'cdecl', 'msvcr71._wstat', (('int', None), ('int', None)) ),
    'msvcr71._wstat64':( 'int', None, 'cdecl', 'msvcr71._wstat64', (('int', None), ('int', None)) ),
    'msvcr71._wstati64':( 'int', None, 'cdecl', 'msvcr71._wstati64', (('int', None), ('int', None)) ),
    'msvcr71._wstrdate':( 'int', None, 'cdecl', 'msvcr71._wstrdate', (('int', None),) ),
    'msvcr71._wstrtime':( 'int', None, 'cdecl', 'msvcr71._wstrtime', (('int', None),) ),
    'msvcr71._wsystem':( 'int', None, 'cdecl', 'msvcr71._wsystem', (('int', None),) ),
    'msvcr71._wtempnam':( 'int', None, 'cdecl', 'msvcr71._wtempnam', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71._wtmpnam':( 'int', None, 'cdecl', 'msvcr71._wtmpnam', (('int', None),) ),
    'msvcr71._wtof':( 'int', None, 'cdecl', 'msvcr71._wtof', (('void *', 'ptr'),) ),
    'msvcr71._wtoi':( 'int', None, 'cdecl', 'msvcr71._wtoi', (('int', None),) ),
    'msvcr71._wtoi64':( 'int', None, 'cdecl', 'msvcr71._wtoi64', (('int', None),) ),
    'msvcr71._wtol':( 'int', None, 'cdecl', 'msvcr71._wtol', (('int', None),) ),
    'msvcr71._wunlink':( 'int', None, 'cdecl', 'msvcr71._wunlink', (('int', None),) ),
    'msvcr71._wutime':( 'int', None, 'cdecl', 'msvcr71._wutime', (('StringW', None), ('void *', 'ptr')) ),
    'msvcr71._wutime64':( 'int', None, 'cdecl', 'msvcr71._wutime64', (('StringW', None), ('void *', 'ptr')) ),
    'msvcr71._y0':( 'int', None, 'cdecl', 'msvcr71._y0', () ),
    'msvcr71._y1':( 'int', None, 'cdecl', 'msvcr71._y1', () ),
    'msvcr71._yn':( 'int', None, 'cdecl', 'msvcr71._yn', () ),
    'msvcr71.abort':( 'int', None, 'stdcall', 'msvcr71.abort', (('int', None),) ),
    'msvcr71.abs':( 'int', None, 'cdecl', 'msvcr71.abs', (('int', None),) ),
    'msvcr71.acos':( 'int', None, 'cdecl', 'msvcr71.acos', () ),
    'msvcr71.asctime':( 'int', None, 'cdecl', 'msvcr71.asctime', (('int', None),) ),
    'msvcr71.asin':( 'int', None, 'cdecl', 'msvcr71.asin', () ),
    'msvcr71.atan':( 'int', None, 'cdecl', 'msvcr71.atan', () ),
    'msvcr71.atan2':( 'int', None, 'cdecl', 'msvcr71.atan2', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.atexit':( 'int', None, 'cdecl', 'msvcr71.atexit', (('int', None),) ),
    'msvcr71.atof':( 'int', None, 'cdecl', 'msvcr71.atof', (('void *', 'ptr'),) ),
    'msvcr71.atoi':( 'int', None, 'cdecl', 'msvcr71.atoi', (('int', None),) ),
    'msvcr71.atol':( 'int', None, 'cdecl', 'msvcr71.atol', (('void *', 'ptr'),) ),
    'msvcr71.bsearch':( 'int', None, 'cdecl', 'msvcr71.bsearch', (('int', None), ('int', None), ('int', None), ('int', None), ('void *', 'funcptr')) ),
    'msvcr71.calloc':( 'int', None, 'cdecl', 'msvcr71.calloc', (('int', None), ('int', None)) ),
    'msvcr71.ceil':( 'int', None, 'cdecl', 'msvcr71.ceil', () ),
    'msvcr71.clearerr':( 'int', None, 'cdecl', 'msvcr71.clearerr', (('int', None),) ),
    'msvcr71.clock':( 'int', None, 'msfastcall', 'msvcr71.clock', (('int', None), ('int', None)) ),
    'msvcr71.cos':( 'int', None, 'cdecl', 'msvcr71.cos', () ),
    'msvcr71.cosh':( 'int', None, 'cdecl', 'msvcr71.cosh', (('int', None), ('int', None)) ),
    'msvcr71.ctime':( 'int', None, 'cdecl', 'msvcr71.ctime', (('void *', 'ptr'),) ),
    'msvcr71.difftime':( 'int', None, 'cdecl', 'msvcr71.difftime', (('int', None), ('int', None)) ),
    'msvcr71.div':( 'int', None, 'cdecl', 'msvcr71.div', (('int', None), ('int', None)) ),
    'msvcr71.exit':( 'int', None, 'cdecl', 'msvcr71.exit', (('int', None),) ),
    'msvcr71.exp':( 'int', None, 'cdecl', 'msvcr71.exp', (('int', None), ('int', None)) ),
    'msvcr71.fabs':( 'int', None, 'cdecl', 'msvcr71.fabs', (('int', None), ('int', None)) ),
    'msvcr71.fclose':( 'int', None, 'cdecl', 'msvcr71.fclose', (('int', None),) ),
    'msvcr71.feof':( 'int', None, 'cdecl', 'msvcr71.feof', (('int', None),) ),
    'msvcr71.ferror':( 'int', None, 'cdecl', 'msvcr71.ferror', (('int', None),) ),
    'msvcr71.fflush':( 'int', None, 'cdecl', 'msvcr71.fflush', (('int', None),) ),
    'msvcr71.fgetc':( 'int', None, 'cdecl', 'msvcr71.fgetc', (('int', None),) ),
    'msvcr71.fgetpos':( 'int', None, 'cdecl', 'msvcr71.fgetpos', (('int', None), ('int', None)) ),
    'msvcr71.fgets':( 'int', None, 'cdecl', 'msvcr71.fgets', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.fgetwc':( 'int', None, 'cdecl', 'msvcr71.fgetwc', (('int', None),) ),
    'msvcr71.fgetws':( 'int', None, 'cdecl', 'msvcr71.fgetws', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.floor':( 'int', None, 'cdecl', 'msvcr71.floor', () ),
    'msvcr71.fmod':( 'int', None, 'cdecl', 'msvcr71.fmod', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.fopen':( 'int', None, 'cdecl', 'msvcr71.fopen', (('StringA', None), ('int', None)) ),
    'msvcr71.fprintf':( 'int', None, 'cdecl', 'msvcr71.fprintf', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.fputc':( 'int', None, 'cdecl', 'msvcr71.fputc', (('int', None), ('void *', 'ptr')) ),
    'msvcr71.fputs':( 'int', None, 'cdecl', 'msvcr71.fputs', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.fputwc':( 'int', None, 'cdecl', 'msvcr71.fputwc', (('int', None), ('int', None)) ),
    'msvcr71.fputws':( 'int', None, 'cdecl', 'msvcr71.fputws', (('int', None), ('int', None)) ),
    'msvcr71.fread':( 'int', None, 'cdecl', 'msvcr71.fread', (('StringA', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.free':( 'void', None, 'cdecl', 'msvcr71.free', (('void *', 'ptr'),) ),
    'msvcr71.freopen':( 'int', None, 'cdecl', 'msvcr71.freopen', (('StringA', None), ('int', None), ('int', None)) ),
    'msvcr71.frexp':( 'int', None, 'cdecl', 'msvcr71.frexp', () ),
    'msvcr71.fscanf':( 'int', None, 'cdecl', 'msvcr71.fscanf', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.fseek':( 'int', None, 'cdecl', 'msvcr71.fseek', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.fsetpos':( 'int', None, 'cdecl', 'msvcr71.fsetpos', (('int', None), ('int', None)) ),
    'msvcr71.ftell':( 'int', None, 'cdecl', 'msvcr71.ftell', (('int', None),) ),
    'msvcr71.fwprintf':( 'int', None, 'cdecl', 'msvcr71.fwprintf', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.fwrite':( 'int', None, 'cdecl', 'msvcr71.fwrite', (('void *', 'ptr'), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.fwscanf':( 'int', None, 'cdecl', 'msvcr71.fwscanf', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.getc':( 'int', None, 'cdecl', 'msvcr71.getc', (('int', None),) ),
    'msvcr71.getchar':( 'int', None, 'cdecl', 'msvcr71.getchar', () ),
    'msvcr71.getenv':( 'int', None, 'cdecl', 'msvcr71.getenv', (('void *', 'ptr'),) ),
    'msvcr71.gets':( 'int', None, 'cdecl', 'msvcr71.gets', (('int', None),) ),
    'msvcr71.getwc':( 'int', None, 'cdecl', 'msvcr71.getwc', (('int', None),) ),
    'msvcr71.getwchar':( 'int', None, 'cdecl', 'msvcr71.getwchar', () ),
    'msvcr71.gmtime':( 'int', None, 'cdecl', 'msvcr71.gmtime', (('void *', 'ptr'),) ),
    'msvcr71.is_wctype':( 'int', None, 'cdecl', 'msvcr71.is_wctype', (('int', None), ('int', None)) ),
    'msvcr71.isalnum':( 'int', None, 'cdecl', 'msvcr71.isalnum', (('int', None),) ),
    'msvcr71.isalpha':( 'int', None, 'cdecl', 'msvcr71.isalpha', (('int', None),) ),
    'msvcr71.iscntrl':( 'int', None, 'cdecl', 'msvcr71.iscntrl', (('int', None),) ),
    'msvcr71.isdigit':( 'int', None, 'cdecl', 'msvcr71.isdigit', (('int', None),) ),
    'msvcr71.isgraph':( 'int', None, 'cdecl', 'msvcr71.isgraph', (('int', None),) ),
    'msvcr71.isleadbyte':( 'int', None, 'cdecl', 'msvcr71.isleadbyte', (('int', None),) ),
    'msvcr71.islower':( 'int', None, 'cdecl', 'msvcr71.islower', (('int', None),) ),
    'msvcr71.isprint':( 'int', None, 'cdecl', 'msvcr71.isprint', (('int', None),) ),
    'msvcr71.ispunct':( 'int', None, 'cdecl', 'msvcr71.ispunct', (('int', None),) ),
    'msvcr71.isspace':( 'int', None, 'cdecl', 'msvcr71.isspace', (('int', None),) ),
    'msvcr71.isupper':( 'int', None, 'cdecl', 'msvcr71.isupper', (('int', None),) ),
    'msvcr71.iswalnum':( 'int', None, 'cdecl', 'msvcr71.iswalnum', (('int', None),) ),
    'msvcr71.iswalpha':( 'int', None, 'cdecl', 'msvcr71.iswalpha', (('int', None),) ),
    'msvcr71.iswascii':( 'int', None, 'cdecl', 'msvcr71.iswascii', (('int', None),) ),
    'msvcr71.iswcntrl':( 'int', None, 'cdecl', 'msvcr71.iswcntrl', (('int', None),) ),
    'msvcr71.iswctype':( 'int', None, 'cdecl', 'msvcr71.iswctype', (('int', None), ('int', None)) ),
    'msvcr71.iswdigit':( 'int', None, 'cdecl', 'msvcr71.iswdigit', (('int', None),) ),
    'msvcr71.iswgraph':( 'int', None, 'cdecl', 'msvcr71.iswgraph', (('int', None),) ),
    'msvcr71.iswlower':( 'int', None, 'cdecl', 'msvcr71.iswlower', (('int', None),) ),
    'msvcr71.iswprint':( 'int', None, 'cdecl', 'msvcr71.iswprint', (('int', None),) ),
    'msvcr71.iswpunct':( 'int', None, 'cdecl', 'msvcr71.iswpunct', (('int', None),) ),
    'msvcr71.iswspace':( 'int', None, 'cdecl', 'msvcr71.iswspace', (('int', None),) ),
    'msvcr71.iswupper':( 'int', None, 'cdecl', 'msvcr71.iswupper', (('int', None),) ),
    'msvcr71.iswxdigit':( 'int', None, 'cdecl', 'msvcr71.iswxdigit', (('int', None),) ),
    'msvcr71.isxdigit':( 'int', None, 'cdecl', 'msvcr71.isxdigit', (('int', None),) ),
    'msvcr71.labs':( 'int', None, 'cdecl', 'msvcr71.labs', (('int', None),) ),
    'msvcr71.ldexp':( 'int', None, 'cdecl', 'msvcr71.ldexp', (('int', None), ('int', None)) ),
    'msvcr71.ldiv':( 'int', None, 'cdecl', 'msvcr71.ldiv', (('int', None), ('int', None)) ),
    'msvcr71.localeconv':( 'int', None, 'cdecl', 'msvcr71.localeconv', () ),
    'msvcr71.localtime':( 'int', None, 'cdecl', 'msvcr71.localtime', (('void *', 'ptr'),) ),
    'msvcr71.log':( 'int', None, 'cdecl', 'msvcr71.log', () ),
    'msvcr71.log10':( 'int', None, 'cdecl', 'msvcr71.log10', () ),
    'msvcr71.longjmp':( 'int', None, 'cdecl', 'msvcr71.longjmp', (('int', None), ('int', None)) ),
    'msvcr71.malloc':( 'int', None, 'cdecl', 'msvcr71.malloc', (('DWORD', None),) ),
    'msvcr71.mblen':( 'int', None, 'cdecl', 'msvcr71.mblen', (('int', None), ('int', None)) ),
    'msvcr71.mbstowcs':( 'int', None, 'cdecl', 'msvcr71.mbstowcs', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.mbtowc':( 'int', None, 'cdecl', 'msvcr71.mbtowc', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.memchr':( 'int', None, 'cdecl', 'msvcr71.memchr', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.memcmp':( 'int', None, 'cdecl', 'msvcr71.memcmp', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.memcpy':( 'int', None, 'cdecl', 'msvcr71.memcpy', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.memmove':( 'int', None, 'cdecl', 'msvcr71.memmove', (('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.memset':( 'int', None, 'cdecl', 'msvcr71.memset', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.mktime':( 'int', None, 'cdecl', 'msvcr71.mktime', (('int', None),) ),
    'msvcr71.modf':( 'int', None, 'cdecl', 'msvcr71.modf', (('int', None), ('int', None)) ),
    'msvcr71.perror':( 'int', None, 'cdecl', 'msvcr71.perror', (('void *', 'ptr'),) ),
    'msvcr71.pow':( 'int', None, 'cdecl', 'msvcr71.pow', () ),
    'msvcr71.printf':( 'int', None, 'cdecl', 'msvcr71.printf', (('int', None),) ),
    'msvcr71.putc':( 'int', None, 'cdecl', 'msvcr71.putc', (('int', None), ('void *', 'ptr')) ),
    'msvcr71.putchar':( 'int', None, 'cdecl', 'msvcr71.putchar', (('int', None),) ),
    'msvcr71.puts':( 'int', None, 'cdecl', 'msvcr71.puts', (('void *', 'ptr'),) ),
    'msvcr71.putwc':( 'int', None, 'cdecl', 'msvcr71.putwc', (('int', None), ('int', None)) ),
    'msvcr71.putwchar':( 'int', None, 'cdecl', 'msvcr71.putwchar', (('int', None),) ),
    'msvcr71.qsort':( 'int', None, 'stdcall', 'msvcr71.qsort', ( ('int', None), ('int', None), ('void *', 'funcptr'), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.quick_exit':( 'int', None, 'cdecl', 'msvcr71.quick_exit', (('int', None),) ),
    'msvcr71.raise':( 'int', None, 'cdecl', 'msvcr71.raise', (('int', None),) ),
    'msvcr71.rand':( 'int', None, 'cdecl', 'msvcr71.rand', () ),
    'msvcr71.realloc':( 'int', None, 'cdecl', 'msvcr71.realloc', (('void *', 'ptr'), ('DWORD', None)) ),
    'msvcr71.remove':( 'int', None, 'cdecl', 'msvcr71.remove', (('int', None),) ),
    'msvcr71.rename':( 'int', None, 'cdecl', 'msvcr71.rename', (('int', None), ('int', None)) ),
    'msvcr71.rewind':( 'int', None, 'cdecl', 'msvcr71.rewind', (('int', None),) ),
    'msvcr71.scanf':( 'int', None, 'cdecl', 'msvcr71.scanf', (('int', None),) ),
    'msvcr71.setbuf':( 'int', None, 'cdecl', 'msvcr71.setbuf', (('int', None), ('int', None)) ),
    'msvcr71.setlocale':( 'int', None, 'cdecl', 'msvcr71.setlocale', (('int', None), ('void *', 'obj')) ),
    'msvcr71.setvbuf':( 'int', None, 'cdecl', 'msvcr71.setvbuf', (('int', None), ('int', None), ('int', None), ('DWORD', None)) ),
    'msvcr71.signal':( 'int', None, 'cdecl', 'msvcr71.signal', (('int', None), ('int', None)) ),
    'msvcr71.sin':( 'int', None, 'cdecl', 'msvcr71.sin', () ),
    'msvcr71.sinh':( 'int', None, 'cdecl', 'msvcr71.sinh', (('int', None), ('int', None)) ),
    'msvcr71.sprintf':( 'int', None, 'cdecl', 'msvcr71.sprintf', (('int', None), ('int', None)) ),
    'msvcr71.sqrt':( 'int', None, 'cdecl', 'msvcr71.sqrt', () ),
    'msvcr71.srand':( 'int', None, 'cdecl', 'msvcr71.srand', (('int', None),) ),
    'msvcr71.sscanf':( 'int', None, 'cdecl', 'msvcr71.sscanf', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.strcat':( 'int', None, 'cdecl', 'msvcr71.strcat', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71.strchr':( 'int', None, 'cdecl', 'msvcr71.strchr', (('int', None), ('int', None)) ),
    'msvcr71.strcmp':( 'int', None, 'cdecl', 'msvcr71.strcmp', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.strcoll':( 'int', None, 'cdecl', 'msvcr71.strcoll', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71.strcpy':( 'int', None, 'cdecl', 'msvcr71.strcpy', (('void *', 'ptr'), ('void *', 'ptr')) ),
    'msvcr71.strcspn':( 'int', None, 'cdecl', 'msvcr71.strcspn', (('int', None), ('int', None)) ),
    'msvcr71.strerror':( 'int', None, 'cdecl', 'msvcr71.strerror', (('int', None),) ),
    'msvcr71.strftime':( 'int', None, 'cdecl', 'msvcr71.strftime', (('void *', 'ptr'), ('int', None), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.strlen':( 'int', None, 'cdecl', 'msvcr71.strlen', (('void *', 'ptr'),) ),
    'msvcr71.strncat':( 'int', None, 'cdecl', 'msvcr71.strncat', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.strncmp':( 'int', None, 'cdecl', 'msvcr71.strncmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.strncpy':( 'int', None, 'cdecl', 'msvcr71.strncpy', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.strpbrk':( 'int', None, 'cdecl', 'msvcr71.strpbrk', (('int', None), ('int', None)) ),
    'msvcr71.strrchr':( 'int', None, 'cdecl', 'msvcr71.strrchr', (('int', None), ('int', None)) ),
    'msvcr71.strspn':( 'int', None, 'cdecl', 'msvcr71.strspn', (('int', None), ('int', None)) ),
    'msvcr71.strstr':( 'int', None, 'cdecl', 'msvcr71.strstr', (('int', None), ('void *', 'ptr')) ),
    'msvcr71.strtod':( 'int', None, 'cdecl', 'msvcr71.strtod', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.strtok':( 'int', None, 'cdecl', 'msvcr71.strtok', (('int', None), ('int', None)) ),
    'msvcr71.strtol':( 'int', None, 'cdecl', 'msvcr71.strtol', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.strtoul':( 'int', None, 'cdecl', 'msvcr71.strtoul', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.strxfrm':( 'int', None, 'cdecl', 'msvcr71.strxfrm', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.swprintf':( 'int', None, 'cdecl', 'msvcr71.swprintf', (('int', None), ('int', None)) ),
    'msvcr71.swscanf':( 'int', None, 'cdecl', 'msvcr71.swscanf', (('int', None), ('int', None)) ),
    'msvcr71.system':( 'int', None, 'cdecl', 'msvcr71.system', (('int', None),) ),
    'msvcr71.tan':( 'int', None, 'cdecl', 'msvcr71.tan', () ),
    'msvcr71.tanh':( 'int', None, 'cdecl', 'msvcr71.tanh', (('int', None), ('int', None)) ),
    'msvcr71.time':( 'int', None, 'cdecl', 'msvcr71.time', (('void *', 'ptr'),) ),
    'msvcr71.tmpfile':( 'int', None, 'cdecl', 'msvcr71.tmpfile', () ),
    'msvcr71.tmpnam':( 'int', None, 'cdecl', 'msvcr71.tmpnam', (('void *', 'ptr'),) ),
    'msvcr71.tolower':( 'int', None, 'cdecl', 'msvcr71.tolower', (('int', None),) ),
    'msvcr71.toupper':( 'int', None, 'cdecl', 'msvcr71.toupper', (('int', None),) ),
    'msvcr71.towlower':( 'int', None, 'cdecl', 'msvcr71.towlower', (('int', None),) ),
    'msvcr71.towupper':( 'int', None, 'cdecl', 'msvcr71.towupper', (('int', None),) ),
    'msvcr71.ungetc':( 'int', None, 'cdecl', 'msvcr71.ungetc', (('int', None), ('int', None)) ),
    'msvcr71.ungetwc':( 'int', None, 'cdecl', 'msvcr71.ungetwc', (('int', None), ('int', None)) ),
    'msvcr71.vfprintf':( 'int', None, 'cdecl', 'msvcr71.vfprintf', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.vfwprintf':( 'int', None, 'cdecl', 'msvcr71.vfwprintf', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.vprintf':( 'int', None, 'cdecl', 'msvcr71.vprintf', (('int', None), ('int', None)) ),
    'msvcr71.vsprintf':( 'int', None, 'cdecl', 'msvcr71.vsprintf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.vswprintf':( 'int', None, 'cdecl', 'msvcr71.vswprintf', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.vwprintf':( 'int', None, 'cdecl', 'msvcr71.vwprintf', (('int', None), ('int', None)) ),
    'msvcr71.wcscat':( 'int', None, 'cdecl', 'msvcr71.wcscat', (('int', None), ('int', None)) ),
    'msvcr71.wcschr':( 'int', None, 'cdecl', 'msvcr71.wcschr', (('int', None), ('int', None)) ),
    'msvcr71.wcscmp':( 'int', None, 'cdecl', 'msvcr71.wcscmp', (('int', None), ('int', None)) ),
    'msvcr71.wcscoll':( 'int', None, 'cdecl', 'msvcr71.wcscoll', (('int', None), ('int', None)) ),
    'msvcr71.wcscpy':( 'int', None, 'cdecl', 'msvcr71.wcscpy', (('int', None), ('void *', 'ptr')) ),
    'msvcr71.wcscspn':( 'int', None, 'cdecl', 'msvcr71.wcscspn', (('int', None), ('int', None)) ),
    'msvcr71.wcsftime':( 'int', None, 'cdecl', 'msvcr71.wcsftime', (('int', None), ('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcslen':( 'int', None, 'cdecl', 'msvcr71.wcslen', (('void *', 'ptr'),) ),
    'msvcr71.wcsncat':( 'int', None, 'cdecl', 'msvcr71.wcsncat', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcsncmp':( 'int', None, 'cdecl', 'msvcr71.wcsncmp', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcsncpy':( 'int', None, 'cdecl', 'msvcr71.wcsncpy', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcspbrk':( 'int', None, 'cdecl', 'msvcr71.wcspbrk', (('int', None), ('int', None)) ),
    'msvcr71.wcsrchr':( 'int', None, 'cdecl', 'msvcr71.wcsrchr', (('int', None), ('int', None)) ),
    'msvcr71.wcsspn':( 'int', None, 'cdecl', 'msvcr71.wcsspn', (('int', None), ('int', None)) ),
    'msvcr71.wcsstr':( 'int', None, 'cdecl', 'msvcr71.wcsstr', (('int', None), ('int', None)) ),
    'msvcr71.wcstod':( 'int', None, 'cdecl', 'msvcr71.wcstod', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.wcstok':( 'int', None, 'cdecl', 'msvcr71.wcstok', (('int', None), ('int', None)) ),
    'msvcr71.wcstol':( 'int', None, 'cdecl', 'msvcr71.wcstol', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcstombs':( 'int', None, 'cdecl', 'msvcr71.wcstombs', (('void *', 'ptr'), ('void *', 'ptr'), ('int', None)) ),
    'msvcr71.wcstoul':( 'int', None, 'cdecl', 'msvcr71.wcstoul', (('int', None), ('int', None), ('int', None)) ),
    'msvcr71.wcsxfrm':( 'int', None, 'cdecl', 'msvcr71.wcsxfrm', (('void *', 'ptr'), ('int', None), ('int', None)) ),
    'msvcr71.wctomb':( 'int', None, 'cdecl', 'msvcr71.wctomb', (('void *', 'ptr'), ('int', None)) ),
    'msvcr71.wprintf':( 'int', None, 'cdecl', 'msvcr71.wprintf', (('int', None),) ),
    'msvcr71.wscanf':( 'int', None, 'cdecl', 'msvcr71.wscanf', (('int', None),) ),
    }
